| **KeyASCII**   | **ASCII** | **Description**                 |
| -------------- | --------- | ------------------------------- |
| K_BACKSPACE    | \b        | 退格键（Backspace）                  |
| K_TAB          | \t        | 制表键（Tab）                        |
| K_CLEAR        |           | 清楚键（Clear）                      |
| K_RETURN       | \r        | 回车键（Enter）                      |
| K_PAUSE        |           | 暂停键（Pause）                      |
| K_ESCAPE       | ^[        | 退出键（Escape）                     |
| K_SPACE        |           | 空格键（Space）                      |
| K_EXCLAIM      | !         | 感叹号（exclaim）                    |
| K_QUOTEDBL     | "         | 双引号（quotedbl）                   |
| K_HASH         | #         | 井号（hash）                        |
| K_DOLLAR       | $         | 美元符号（dollar）                    |
| K_AMPERSAND    | &         | and 符号（ampersand）               |
| K_QUOTE        | '         | 单引号（quote）                      |
| K_LEFTPAREN    | (         | 左小括号（left parenthesis）          |
| K_RIGHTPAREN   | )         | 右小括号（right parenthesis）         |
| K_ASTERISK     | *         | 星号（asterisk）                    |
| K_PLUS         | +         | 加号（plus sign）                   |
| K_COMMA        | ,         | 逗号（comma）                       |
| K_MINUS        | -         | 减号（minus sign）                  |
| K_PERIOD       | .         | 句号（period）                      |
| K_SLASH        | /         | 正斜杠（forward slash）              |
| K_0            | 0         | 0                               |
| K_1            | 1         | 1                               |
| K_2            | 2         | 2                               |
| K_3            | 3         | 3                               |
| K_4            | 4         | 4                               |
| K_5            | 5         | 5                               |
| K_6            | 6         | 6                               |
| K_7            | 7         | 7                               |
| K_8            | 8         | 8                               |
| K_9            | 9         | 9                               |
| K_COLON        | :         | 冒号（colon）                       |
| K_SEMICOLON    | ;         | 分号（semicolon）                   |
| K_LESS         | <         | 小于号（less-than sign）             |
| K_EQUALS       | =         | 等于号（equals sign）                |
| K_GREATER      | >         | 大于号（greater-than sign）          |
| K_QUESTION     | ?         | 问号（question mark）               |
| K_AT           | @         | at 符号（at）                       |
| K_LEFTBRACKET  | [         | 左中括号（left bracket）              |
| K_BACKSLASH    | \         | 反斜杠（backslash）                  |
| K_RIGHTBRACKET | ]         | 右中括号（right bracket）             |
| K_CARET        | ^         | 脱字符（caret）                      |
| K_UNDERSCORE   | _         | 下划线（underscore）                 |
| K_BACKQUOTE    | `         | 重音符（grave）                      |
| K_a            | a         | a                               |
| K_b            | b         | b                               |
| K_c            | c         | c                               |
| K_d            | d         | d                               |
| K_e            | e         | e                               |
| K_f            | f         | f                               |
| K_g            | g         | g                               |
| K_h            | h         | h                               |
| K_i            | i         | i                               |
| K_j            | j         | j                               |
| K_k            | k         | k                               |
| K_l            | l         | l                               |
| K_m            | m         | m                               |
| K_n            | n         | n                               |
| K_o            | o         | o                               |
| K_p            | p         | p                               |
| K_q            | q         | q                               |
| K_r            | r         | r                               |
| K_s            | s         | s                               |
| K_t            | t         | t                               |
| K_u            | u         | u                               |
| K_v            | v         | v                               |
| K_w            | w         | w                               |
| K_x            | x         | x                               |
| K_y            | y         | y                               |
| K_z            | z         | z                               |
| K_DELETE       |           | 删除键（delete）                     |
| K_KP0          |           | 0（小键盘）                          |
| K_KP1          |           | 1（小键盘）                          |
| K_KP2          |           | 2（小键盘）                          |
| K_KP3          |           | 3（小键盘）                          |
| K_KP4          |           | 4（小键盘）                          |
| K_KP5          |           | 5（小键盘）                          |
| K_KP6          |           | 6（小键盘）                          |
| K_KP7          |           | 7（小键盘）                          |
| K_KP8          |           | 8（小键盘）                          |
| K_KP9          |           | 9（小键盘）                          |
| K_KP_PERIOD    | .         | 句号（小键盘）                         |
| K_KP_DIVIDE    | /         | 除号（小键盘）                         |
| K_KP_MULTIPLY  | *         | 乘号（小键盘）                         |
| K_KP_MINUS     | -         | 减号（小键盘）                         |
| K_KP_PLUS      | +         | 加号（小键盘）                         |
| K_KP_ENTER     | \r        | 回车键（小键盘）                        |
| K_KP_EQUALS    | =         | 等于号（小键盘）                        |
| K_UP           |           | 向上箭头（up arrow）                  |
| K_DOWN         |           | 向下箭头（down arrow）                |
| K_RIGHT        |           | 向右箭头（right arrow）               |
| K_LEFT         |           | 向左箭头（left arrow）                |
| K_INSERT       |           | 插入符（insert）                     |
| K_HOME         |           | Home 键（home）                    |
| K_END          |           | End 键（end）                      |
| K_PAGEUP       |           | 上一页（page up）                    |
| K_PAGEDOWN     |           | 下一页（page down）                  |
| K_F1           |           | F1                              |
| K_F2           |           | F2                              |
| K_F3           |           | F3                              |
| K_F4           |           | F4                              |
| K_F5           |           | F5                              |
| K_F6           |           | F6                              |
| K_F7           |           | F7                              |
| K_F8           |           | F8                              |
| K_F9           |           | F9                              |
| K_F10          |           | F10                             |
| K_F11          |           | F11                             |
| K_F12          |           | F12                             |
| K_F13          |           | F13                             |
| K_F14          |           | F14                             |
| K_F15          |           | F15                             |
| K_NUMLOCK      |           | 数字键盘锁定键（numlock）                |
| K_CAPSLOCK     |           | 大写字母锁定键（capslock）               |
| K_SCROLLOCK    |           | 滚动锁定键（scrollock）                |
| K_RSHIFT       |           | 右边的 shift 键（right shift）        |
| K_LSHIFT       |           | 左边的 shift 键（left shift）         |
| K_RCTRL        |           | 右边的 ctrl 键（right ctrl）          |
| K_LCTRL        |           | 左边的 ctrl 键（left ctrl）           |
| K_RALT         |           | 右边的 alt 键（right alt）            |
| K_LALT         |           | 左边的 alt 键（left alt）             |
| K_RMETA        |           | 右边的元键（right meta）               |
| K_LMETA        |           | 左边的元键（left meta）                |
| K_LSUPER       |           | 左边的 Window 键（left windows key）  |
| K_RSUPER       |           | 右边的 Window 键（right windows key） |
| K_MODE         |           | 模式转换键（mode shift）               |
| K_HELP         |           | 帮助键（help）                       |
| K_PRINT        |           | 打印屏幕键（print screen）             |
| K_SYSREQ       |           | 魔术键（sysrq）                      |
| K_BREAK        |           | 中断键（break）                      |
| K_MENU         |           | 菜单键（menu）                       |
| K_POWER        |           | 电源键（power）                      |
| K_EURO         |           | 欧元符号（euro）                      |